/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/
#ifndef FSGJT_ENUMS_H
#define FSGJT_ENUMS_H

/************************************************************
 * BindingTypeEnum
 *
 * Whether or not to bind and what kind of binding to use.
 ***********************************************************/
#define FSGJT_BD_CHANNEL      "CHANNEL" 
#define FSGJT_BD_EDGE_GLUE    "EDGE_GLUE"
#define FSGJT_BD_NONE         "NONE"
#define FSGJT_BD_PERFECT      "PERFECT"
#define FSGJT_BD_PLASTIC_COMB "PLASTIC_COMB"
#define FSGJT_BD_RING         "RING"
#define FSGJT_BD_SPIRAL       "SPIRAL"
#define FSGJT_BD_STRIP        "STRIP"
#define FSGJT_BD_TAPE         "TAPE"
#define FSGJT_BD_THREAD_SEAL  "THREAD_SEAL"
#define FSGJT_BD_VELO         "VELO"
#define FSGJT_BD_WIRE_COMB    "WIRE_COMB"

/************************************************************ 
 * Boolean type 
 *
 * Used for boolean values. 
 ***********************************************************/
typedef int fsgjt_boolean_t;
#define true   1
#define false  0
#define not_set -1

/************************************************************
 * CollateEnum
 *
 * Whether the sheets and/or documents are to be collated or 
 * not.
 ***********************************************************/
typedef enum
{
   FSGJT_CL_NOT_SET = 0,
   FSGJT_CL_NONE,
   FSGJT_CL_SHEET,
   FSGJT_CL_SHEET_AND_DOC
} fsgjt_collate_t;

/************************************************************
 * CompressionEnum
 *
 * Type of compression algorithm to use for the data 
 * contained in the document.
 ***********************************************************/
#define FSGJT_CM_COMPRESS "COMPRESS"
#define FSGJT_CM_DEFLATE  "DEFLATE" 
#define FSGJT_CM_GZIP     "GZIP"
#define FSGJT_CM_NONE     "NONE"

/************************************************************
 * ContactTypeEnum
 *
 * Role of the person that is to be contacted regarding the
 * job.
 ***********************************************************/
#define FSGJT_CT_ACCOUNTING     "ACCOUNTING"
#define FSGJT_CT_ADMINISTRATOR  "ADMINISTRATOR"
#define FSGJT_CT_APPROVER       "APPROVER"
#define FSGJT_CT_ART_RETURN     "ART_RETURN"
#define FSGJT_CT_CUSTOMER       "CUSTOMER" 
#define FSGJT_CT_DELIVERY       "DELIVERY"
#define FSGJT_CT_PICKUP         "PICKUP"
#define FSGJT_CT_SENDER         "SENDER"
#define FSGJT_CT_SUPPLIER       "SUPPLIER" 
#define FSGJT_CT_SURPLUS_RETURN "SURPLUS_RETURN"

/************************************************************
 * FeedOrientation
 * 
 * The orientation of the media as it is to be fed into the
 * device.
 ***********************************************************/
typedef enum
{
   FSGJT_FO_NOT_SET = 0,
   FSGJT_FO_LONG_EDGE_FIRST,
   FSGJT_FO_SHORT_EDGE_FIRST,
} fsgjt_feed_orientation_t;

/************************************************************
 * FitPolicyEnum
 * 
 * How to modify the content to fit on the media.
 ***********************************************************/
typedef enum
{
   FSGJT_FP_NOT_SET = 0,
   FSGJT_FP_CLIP_TO_PAGE,
   FSGJT_FP_FIT_TO_PAGE,
   FSGJT_FP_ROTATE_AND_OR_FIT
} fsgjt_fit_policy_t;

/************************************************************
 * FoldTypeEnum
 *
 * The type of folding to perform.
 ***********************************************************/
#define FSGJT_FD_NONE           "NONE"
#define FSGJT_FD_SADDLE         "SADDLE"
#define FSGJT_FD_Z              "Z"
#define FSGJT_FD_Z_IN_THIRDS    "Z_IN_THIRDS"
#define FSGJT_FD_C              "C"

/************************************************************
 * HoldEnum
 *
 * Whether or not to hold the job and for how long.
 ***********************************************************/
#define FSGJT_HD_NO_HOLD     "NO_HOLD"
#define FSGJT_HD_INDEFINITE  "INDEFINITE"

/************************************************************
 * ImageAlignmentXEnum
 *
 * How to align the image in the x direction.
 ***********************************************************/
typedef enum
{
   FSGJT_IAX_NOT_SET = 0,
   FSGJT_IAX_NONE,
   FSGJT_IAX_CENTER,
   FSGJT_IAX_LEFT,
   FSGJT_IAX_RIGHT, 
} fsgjt_image_alignement_x_t;

/************************************************************
 * ImageAlignmentYEnum
 *
 * How to align the image in the y direction.
 ***********************************************************/
typedef enum
{
   FSGJT_IAY_NOT_SET = 0,
   FSGJT_IAY_NONE,
   FSGJT_IAY_BOTTOM,
   FSGJT_IAY_CENTER,
   FSGJT_IAY_TOP 
} fsgjt_image_alignement_y_t;

/************************************************************
 * InputTrayNameEnum
 *
 * Names of the input trays.
 ***********************************************************/
#define FSGJT_IT_ANY_SMALL_FORMAT "ANY_SMALL_FORMAT"
#define FSGJT_IT_ANY_LARGE_FORMAT "ANY_LARGE_FORMAT"
#define FSGJT_IT_AUTO_SELECT      "AUTO_SELECT"
#define FSGJT_IT_BOTTOM           "BOTTOM"
#define FSGJT_IT_BYPASS_TRAY      "BYPASS_TRAY"
#define FSGJT_IT_BYPASS_TRAY_1    "BYPASS_TRAY_1"
#define FSGJT_IT_BYPASS_TRAY_2    "BYPASS_TRAY_2"
#define FSGJT_IT_BYPASS_TRAY_3    "BYPASS_TRAY_3"
#define FSGJT_IT_CONTINUOUS       "CONTINUOUS"
#define FSGJT_IT_DISC             "DISC" 
#define FSGJT_IT_DISC_1           "DISC_1" 
#define FSGJT_IT_DISC_2           "DISC_2" 
#define FSGJT_IT_DISC_3           "DISC_3"        
#define FSGJT_IT_ENVELOPE         "ENVELOPE"
#define FSGJT_IT_ENVELOPE_1       "ENVELOPE_1"
#define FSGJT_IT_ENVELOPE_2       "ENVELOPE_2"
#define FSGJT_IT_ENVELOPE_3       "ENVELOPE_3"
#define FSGJT_IT_FRONT            "FRONT"
#define FSGJT_IT_INSERT_TRAY      "INSERT_TRAY"
#define FSGJT_IT_INSERT_TRAY_1    "INSERT_TRAY_1"
#define FSGJT_IT_INSERT_TRAY_2    "INSERT_TRAY_2"
#define FSGJT_IT_INSERT_TRAY_3    "INSERT_TRAY_3"
#define FSGJT_IT_LARGE_CAPACITY   "LARGE_CAPACITY"
#define FSGJT_IT_LARGE_CAPACITY_1 "LARGE_CAPACITY_1"
#define FSGJT_IT_LARGE_CAPACITY_2 "LARGE_CAPACITY_2"
#define FSGJT_IT_LARGE_CAPACITY_3 "LARGE_CAPACITY_3"
#define FSGJT_IT_LEFT             "LEFT"
#define FSGJT_IT_MIDDLE           "MIDDLE"
#define FSGJT_IT_REAR             "REAR"
#define FSGJT_IT_RIGHT            "RIGHT"
#define FSGJT_IT_ROLL             "ROLL" 
#define FSGJT_IT_ROLL_1           "ROLL_1"
#define FSGJT_IT_ROLL_2           "ROLL_2"
#define FSGJT_IT_ROLL_3           "ROLL_3"
#define FSGJT_IT_SIDE             "SIDE"
#define FSGJT_IT_TOP              "TOP"
#define FSGJT_IT_TRAY             "TRAY"
#define FSGJT_IT_TRAY_1           "TRAY_1"
#define FSGJT_IT_TRAY_2           "TRAY_2"
#define FSGJT_IT_TRAY_3           "TRAY_3"

/************************************************************
 * InsertSheetContentEnum
 *
 * What is to appear on the insert sheet.
 ***********************************************************/
typedef enum
{
   FSGJT_IC_NOT_SET = 0,
   FSGJT_IC_BLANK,
   FSGJT_IC_DUPLICATE
} fsgjt_insert_sheet_content_t;

/************************************************************
 * JobTicketTypeVersionEnum
 *
 * Type and version of the job ticket syntax.
 ***********************************************************/
#define FSGJT_JT_AUTO_DETECT "AUTO_DETECT"
#define FSGJT_JT_JDF_1_2     "JDF_1.2"
#define FSGJT_JT_OTHER       "OTHER"
#define FSGJT_JT_PWG         "PWG_1.0"

/************************************************************
 * JogOffsetEnum
 *
 * Whether or not the job and job copies are to be offset 
 * stacked.
 ***********************************************************/
typedef enum
{
   FSGJT_JO_NOT_SET = 0,
   FSGJT_JO_NONE,
   FSGJT_JO_ALTERNATE,
} fsgjt_jog_offset_t;


/************************************************************
 * LengthUnitEnum
 *
 * Unit if measure to use when specifying length.
 ***********************************************************/
typedef enum
{
   FSGJT_LU_NOT_SET = 0,
   FSGJT_LU_MICROMETERS,
   FSGJT_LU_POINTS,
   FSGJT_LU_TEN_THOUSANDTHS_OF_INCHES
} fsgjt_length_unit_t;

/************************************************************
 * MandatoryAtributesEnum
 *
 * Attributes that are mandatory and must be supported.
 ***********************************************************/
#define FSGJT_MA_ALL  "ALL"
#define FSGJT_MA_NONE "NONE"

/************************************************************
 * MediaCoatingEnum
 *
 * Type of coating on the media.
 ***********************************************************/
typedef enum
{
   FSGJT_MG_NOT_SET = 0,
   FSGJT_MG_NONE,
   FSGJT_MG_COATED,
   FSGJT_MG_GLOSSY,
   FSGJT_MG_HIGH_GLOSS,
   FSGJT_MG_INK_JET,
   FSGJT_MG_MATTE,
   FSGJT_MG_SATIN,
   FSGJT_MG_SEMI_GLOSS
} fsgjt_media_coating_t;

/************************************************************
 * MediaColorEnum
 *
 * Color of the media.
 ***********************************************************/
typedef enum
{
   FSGJT_MC_NOT_SET = 0,
   FSGJT_MC_BLACK,
   FSGJT_MC_CLEAR_BLACK,
   FSGJT_MC_DARK_BLACK, 
   FSGJT_MC_LIGHT_BLACK,
   FSGJT_MC_BLUE, 
   FSGJT_MC_CLEAR_BLUE,
   FSGJT_MC_DARK_BLUE,
   FSGJT_MC_LIGHT_BLUE,
   FSGJT_MC_BROWN,
   FSGJT_MC_CLEAR_BROWN,
   FSGJT_MC_DARK_BROWN,
   FSGJT_MC_LIGHT_BROWN,
   FSGJT_MC_BUFF,
   FSGJT_MC_CLEAR_BUFF,
   FSGJT_MC_DARK_BUFF,
   FSGJT_MC_LIGHT_BUFF,
   FSGJT_MC_CYAN,
   FSGJT_MC_CLEAR_CYAN,        
   FSGJT_MC_DARK_CYAN,
   FSGJT_MC_LIGHT_CYAN,
   FSGJT_MC_GOLD,
   FSGJT_MC_CLEAR_GOLD,
   FSGJT_MC_DARK_GOLD,
   FSGJT_MC_LIGHT_GOLD,
   FSGJT_MC_GOLDENROD,
   FSGJT_MC_CLEAR_GODLENROD,
   FSGJT_MC_DARK_GOLDENROD,
   FSGJT_MC_LIGHT_GOLDENROD,
   FSGJT_MC_GRAY,
   FSGJT_MC_CLEAR_GRAY,
   FSGJT_MC_DARK_GRAY,
   FSGJT_MC_LIGHT_GRAY,
   FSGJT_MC_GREEN,
   FSGJT_MC_CLEAR_GREEN,
   FSGJT_MC_DARK_GREEN,
   FSGJT_MC_LIGHT_GREEN,
   FSGJT_MC_IVORY,
   FSGJT_MC_CLEAR_IVORY,
   FSGJT_MC_DARK_IVORY,
   FSGJT_MC_LIGHT_IVORY,
   FSGJT_MC_MAGENTA,
   FSGJT_MC_CLEAR_MAGENTA,
   FSGJT_MC_DARK_MAGENTA,
   FSGJT_MC_LIGHT_MAGENTA,
   FSGJT_MC_MULTI_COLOR,
   FSGJT_MC_CLEAR_MULTI_COLOR,
   FSGJT_MC_DARK_MULTI_COLOR,
   FSGJT_MC_LIGHT_MULTI_COLOR,
   FSGJT_MC_MUSTARD,
   FSGJT_MC_CLEAR_MUSTARD,
   FSGJT_MC_DARK_MUSTARD,
   FSGJT_MC_LIGHT_MUSTARD,
   FSGJT_MC_NO_COLOR,
   FSGJT_MC_CLEAR_NO_COLOR,
   FSGJT_MC_DARK_NO_COLOR,
   FSGJT_MC_LIGHT_NO_COLOR,
   FSGJT_MC_ORANGE,
   FSGJT_MC_CLEAR_ORANGE,
   FSGJT_MC_DARK_ORANGE,
   FSGJT_MC_LIGHT_ORANGE,
   FSGJT_MC_PINK,
   FSGJT_MC_CLEAR_PINK,
   FSGJT_MC_DARK_PINK,
   FSGJT_MC_LIGHT_PINK,
   FSGJT_MC_RED,
   FSGJT_MC_CLEAR_RED,
   FSGJT_MC_DARK_RED,
   FSGJT_MC_LIGHT_RED,
   FSGJT_MC_SILVER,
   FSGJT_MC_CLEAR_SILVER,
   FSGJT_MC_DARK_SILVER,
   FSGJT_MC_LIGHT_SILVER,
   FSGJT_MC_TURQUOISE,
   FSGJT_MC_CLEAR_TURQUOISE,
   FSGJT_MC_DARK_TURQUOISE,
   FSGJT_MC_LIGHT_TURQUOISE,
   FSGJT_MC_VIOLET,
   FSGJT_MC_CLEAR_VIOLET,
   FSGJT_MC_DARK_VIOLET,
   FSGJT_MC_LIGHT_VIOLET,
   FSGJT_MC_WHITE,
   FSGJT_MC_CLEAR_WHITE,
   FSGJT_MC_DARK_WHITE,
   FSGJT_MC_LIGHT_WHITE,
   FSGJT_MC_YELLOW,
   FSGJT_MC_CLEAR_YELLOW,
   FSGJT_MC_DARK_YELLOW,
   FSGJT_MC_LIGHT_YELLOW
} fsgjt_media_color_t;

/************************************************************
 * MediaTypeEnum
 *
 * Type of the media.
 ***********************************************************/
#define FSGJT_MT_CARD_STOCK	       "CARD_STOCK"
#define FSGJT_MT_CONTINUOUS        "CONTINUOUS"
#define FSGJT_MT_CONTINUOUS_LONG   "CONTINUOUS_LONG"
#define FSGJT_MT_CONTINUOUS_SHORT  "CONTINUOUS_SHORT"  
#define FSGJT_MT_DISC              "DISC"
#define FSGJT_MT_ENVELOPE          "ENVELOPE"
#define FSGJT_MT_ENVELOPE_PLAIN    "ENVELOPE_PLAIN"
#define FSGJT_MT_ENVELOPE_WINDOW   "ENVELOPE_WINDOW"
#define FSGJT_MT_FILM_PHOTOGRAPHIC "FILM_PHOTOGRAPHIC"
#define FSGJT_MT_FILM_BLACK_PRINT  "FILM_BLACK_PRINT"
#define FSGJT_MT_FULL_CUT_TABS     "FULL_CUT_TABS"
#define FSGJT_MT_LABELS            "LABELS"
#define FSGJT_MT_MULTI_LAYER       "MULTI_LAYER"
#define FSGJT_MT_MULTI_PART_FORMS  "MULTI_PART_FORMS"
#define FSGJT_MT_PHOTOGRAPHIC      "PHOTOGRAPHIC"
#define FSGJT_MT_PRE_CUT_TABS      "PRE_CUT_TABS"
#define FSGJT_MT_ROLL              "ROLL" 
#define FSGJT_MT_STATIONERY        "STATIONERY "
#define FSGJT_MT_TAB_STOCK         "TAB_STOCK"
#define FSGJT_MT_TRANSPARENCY      "TRANSPARENCY"

/************************************************************
 * OutputBinEnum
 *
 * Names of output bins.
 ***********************************************************/
#define FSGJT_OB_BOOKLET         "BOOKLET"
#define FSGJT_OB_BOTTOM          "BOTTOM"
#define FSGJT_OB_CENTER          "CENTER"
#define FSGJT_OB_FACE_DOWN       "FACE_DOWN"
#define FSGJT_OB_FACE_UP         "FACE_UP"
#define FSGJT_OB_FIT_MEDIA       "FIT_MEDIA"
#define FSGJT_OB_LARGE_CAPACITY  "LARGE_CAPACITY"
#define FSGJT_OB_LEFT            "LEFT"
#define FSGJT_OB_MAILBOX_1       "MAILBOX_1"
#define FSGJT_OB_MAILBOX_2       "MAILBOX_2"
#define FSGJT_OB_MAILBOX_3       "MAILBOX_3"
#define FSGJT_OB_MIDDLE          "MIDDLE"
#define FSGJT_OB_MY_MAILBOX      "MY_MAILBOX"
#define FSGJT_OB_REAR            "REAR"
#define FSGJT_OB_RIGHT           "RIGHT"
#define FSGJT_OB_SIDE            "SIDE"
#define FSGJT_OB_STACKER_1       "STACKER_1"
#define FSGJT_OB_STACKER_2       "STACKER_2"
#define FSGJT_OB_STACKER_3       "STACKER_3"
#define FSGJT_OB_TOP             "TOP"
#define FSGJT_OB_TRAY_1          "TRAY_1"
#define FSGJT_OB_TRAY_2          "TRAY_2"
#define FSGJT_OB_TRAY_3          "TRAY_3"

/************************************************************
 * PageDeliveryEnum
 *
 * How the pages are to be ordered when output.
 ***********************************************************/
typedef enum
{
   FSGJT_PD_NOT_SET = 0,
   FSGJT_PD_FAN_FOLD,
   FSGJT_PD_REVERSE_ORDER_FACE_DOWN,
   FSGJT_PD_REVERSE_ORDER_FACE_UP,
   FSGJT_PD_SAME_ORDER_FACE_DOWN,
   FSGJT_PD_SAME_ORDER_FACE_UP
} fsgjt_page_delivery_t;

/************************************************************
 * PositionEnum
 *
 * Position from which the operation is to occur.
 ***********************************************************/
typedef enum
{
   FSGJT_PS_NOT_SET = 0,
   FSGJT_PS_AFTER,
   FSGJT_PS_BEFORE
} fsgjt_position_t;

/************************************************************
 * PreprintedEnum
 *
 * Whether or not the media is preprinted.
 ***********************************************************/
#define FSGJT_PP_BLANK
#define FSGJT_PP_LETTERHEAD
#define FSGJT_PP_PREPRINTED

/************************************************************
 * PresentationDirectionEnum
 *
 * Placement order of the pages.
 ***********************************************************/
typedef enum
{
   FSGJT_PR_NOT_SET = 0,
   FSGJT_PR_TO_RIGHT_TO_BOTTOM,
   FSGJT_PR_TO_BOTTOM_TO_RIGHT,
   FSGJT_PR_TO_LEFT_TO_BOTTOM,
   FSGJT_PR_TO_BOTTOM_TO_LEFT,
   FSGJT_PR_TO_RIGHT_TO_TOP,
   FSGJT_PR_TO_TOP_TO_RIGHT,
   FSGJT_PR_TO_LEFT_TO_TOP,
   FSGJT_PR_TO_TOP_TO_LEFT
} fsgjt_presentation_direction_t;

/************************************************************
 * PrintContentOptimizeEnum
 *
 * What to optimize when printing.
 ***********************************************************/
typedef enum
{
   FSGJT_PC_NOT_SET = 0,
   FSGJT_PC_GRAPHICS,  
   FSGJT_PC_PHOTO,  
   FSGJT_PC_TEXT,
   FSGJT_PC_TEXT_AND_GRAPHICS
} fsgjt_print_content_optimize_t;

/************************************************************
 * PrintQualityEnum
 *
 * The quality of the print to produce.
 ***********************************************************/
typedef enum
{
   FSGJT_PQ_NOT_SET = 0,
   FSGJT_PQ_DRAFT,  
   FSGJT_PQ_HIGH,  
   FSGJT_PQ_NORMAL
} fsgjt_print_quality_t;

/************************************************************
 * ReferenceEdgeEnum
 *
 * Reference edge from where the operation is to occur.
 ***********************************************************/
typedef enum
{
   FSGJT_RE_NOT_SET = 0,
   FSGJT_RE_BOTTOM,  
   FSGJT_RE_LEFT,  
   FSGJT_RE_RIGHT,
   FSGJT_RE_TOP
} fsgjt_reference_edge_t;

/************************************************************
 * RotationEnum
 *
 * How much to rotate an image.
 ***********************************************************/
typedef enum
{
   FSGJT_RT_NOT_SET = 0,
   FSGJT_RT_0_DEGREES,
   FSGJT_RT_90_DEGREES,
   FSGJT_RT_180_DEGREES,
   FSGJT_RT_270_DEGREES
} fsgjt_rotation_t;

/************************************************************
 * SeparatorSheetEnum
 *
 * Type of start, separator/slip, end sheets to include 
 * with the job.
 ***********************************************************/
typedef enum
{
   FSGJT_SS_NOT_SET = 0,
   FSGJT_SS_AFTER_DOC_COPIES,
   FSGJT_SS_AFTER_JOB,
   FSGJT_SS_BEFORE_DOC_COPIES,
   FSGJT_SS_BEFORE_JOB,
   FSGJT_SS_BETWEEN_DOC_COPIES,
   FSGJT_SS_BETWEEN_JOB_COPIES,
} fsgjt_separator_sheet_t;

/************************************************************
 * SheetSideEnum
 *
 * Side of the sheet to image on.
 ***********************************************************/
typedef enum
{
   FSGJT_SI_NOT_SET = 0,
   FSGJT_SI_BACK_SIDE,
   FSGJT_SI_FRONT_SIDE
} fsgjt_sheet_side_t;

/************************************************************
 * SidesEnum
 *
 * Sides to image on.
 ***********************************************************/
typedef enum
{
   FSGJT_SD_NOT_SET = 0,
   FSGJT_SD_ONE_SIDED_FRONT,
   FSGJT_SD_ONE_SIDED_LONG_EDGE_BACK,
   FSGJT_SD_ONE_SIDED_SHORT_EDGE_BACK,
   FSGJT_SD_TWO_SIDED_LONG_EDGE,
   FSGJT_SD_TWO_SIDED_SHORT_EDGE
} fsgjt_sides_t;

/************************************************************
 * StitchTypeEnum
 *
 * Whether or not to stitch and where to place the stitch.
 ***********************************************************/
typedef enum
{
   FSGJT_ST_NOT_SET = 0,
   FSGJT_ST_NONE,
   FSGJT_ST_CORNER,
   FSGJT_ST_SADDLE,
   FSGJT_ST_SIDE
} fsgjt_stitch_type_t;

/************************************************************
 * SubscriptionEventEnum
 *
 * Events to subscribe for.
 ***********************************************************/
#define FSGJT_SE_JOB_CREATED        "JOB_CREATED"
#define FSGJT_SE_JOB_COMPLETED      "JOB_COMPLETED"
#define FSGJT_SE_JOB_STOPPED        "JOB_STOPPED"
#define FSGJT_SE_JOB_PROGRESS       "JOB_PROGRESS"
#define FSGJT_SE_JOB_CONFIG_CHANGED "JOB_CONFIG_CHANGED"
#define FSGJT_SE_JOB_STATE_CHANGED  "JOB_STATE_CHANGED"

/************************************************************
 * TrimmingTypeEnum
 *
 * Whether or not to trim pages
 ***********************************************************/
typedef enum
{
   FSGJT_TR_NOT_SET = 0,
   FSGJT_TR_NONE,
   FSGJT_TR_FACE,
   FSGJT_TR_GUTTER,
   FSGJT_TR_TAB,
   FSGJT_TR_TRIM
} fsgjt_trimming_type_t;

/************************************************************
 * ValueTypeEnum
 *
 * The type of an attribute's value(s).
 ***********************************************************/
#define FSGJT_VT_DOUBLE     "VT_DOUBLE"
#define FSGJT_VT_INTEGER    "VT_INTEGER"
#define FSGJT_VT_OBJECT     "VT_OBJECT"
#define FSGJT_VT_STRING     "VT_STRING"

#endif /* FSGJT_ENUMS_H */
